@@ -23,6 +23,9 @@ class RedoSpecGramForm(forms.Form):
     ManualF1 = forms.FloatField(required=False,label='Manual F1')
     ManualF2 = forms.FloatField(required=False,label='Manual F2')
 
+class ResetCacheForm(forms.Form):
+    fields_to_reset = forms.CharField()
+
 class AnalysisForm(forms.Form):
     M_CHOICES = (('N','None'),
                 ('S','SSANOVA-style'),
