@@ -536,7 +536,7 @@ class WordType(caching.base.CachingMixin,models.Model):
         Get the sum of the average durations for all segments in the
         canonical production.
         """
-        return sum([x.getAverageDur() for x in self.UR.all()])
+        return sum([x.get_average_dur() for x in self.UR.all()])
 
     def get_stress_vowel(self):
         """
